# This file contains a complete database schema for all the 
# tables used by WebQuest module, written in SQL

#
# Table structure for table `webquest`
#
CREATE TABLE `prefix_webquest` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `course` int(10) unsigned NOT NULL default '0',
  `name` varchar(255) NOT NULL default '',
  `description` text,
  `process` text,
  `conclussion` text,
  `taskdescription` text,
  `nattachments` tinyint(3) unsigned NOT NULL default '0',
  `gradingstrategy` tinyint(2) unsigned NOT NULL default '1',
  `maxbytes` int(10) unsigned NOT NULL default '100000',
  `submissionstart` int(10) unsigned NOT NULL default '0',
  `submissionend` int(10) unsigned NOT NULL default '0',
  `grade` tinyint(3) NOT NULL default '0',
  `teamsmode` tinyint(3) NOT NULL default '0',
  `timemodified` int(10) unsigned NOT NULL default '0',
  `ntasks` tinyint(3) NOT NULL default '1',
  `usepassword` tinyint(3) unsigned NOT NULL default '0',
  `password` varchar(32) NOT NULL default '',
  PRIMARY KEY  (`id`),
  KEY `course` (`course`)
) COMMENT='Defines webquest';
# --------------------------------------------------------

#
# Table structure for table `webquest_submissions`
#
CREATE TABLE `prefix_webquest_submissions` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `webquestid` int(10) unsigned NOT NULL default '0',
  `title` varchar(100) NOT NULL default '',
  `description` text,
  `userid` int(10) unsigned NOT NULL default '0',
  `timecreated` int(10) unsigned NOT NULL default '0',
  `mailed` tinyint(2) unsigned NOT NULL default '0',
  `timegraded` int(10) unsigned NOT NULL default '0',
  `grade` float NOT NULL default '0',
  `gradecomment` text,
  PRIMARY KEY  (`id`),
  KEY `webquestid` (`webquestid`)
) COMMENT='Submissions';
#------------------------------------------------------------

#
# Table structure for table `webquest_tasks`
#

CREATE TABLE `prefix_webquest_tasks` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `webquestid` int(10) unsigned NOT NULL default '0',
  `taskno` tinyint(3) unsigned NOT NULL default '0',
  `description` text,
  `scale` tinyint(3) unsigned NOT NULL default '0',
  `maxscore` tinyint(3) unsigned NOT NULL default '1',
  `weight` tinyint(3) unsigned NOT NULL default '11',
  `stddev` float NOT NULL default '0.0',
  `totalassessments` int(10) NOT NULL default '0',
  PRIMARY KEY  (`id`),
  KEY `webquestid` (`webquestid`)
) COMMENT='Tasks';
# --------------------------------------------------------

#
# Table structure for table `webquest_rubrics`
#

CREATE TABLE `prefix_webquest_rubrics` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `webquestid` int(10) unsigned NOT NULL default '0',
  `description` text,
  `taskno` int(10) unsigned NOT NULL default '0',
  `rubricno` tinyint(3) unsigned NOT NULL default '0',
  PRIMARY KEY  (`id`),
  KEY `webquestid` (`webquestid`)
) COMMENT='Info about the rubrics';
# --------------------------------------------------------

#
# Table structure for table `webquest_grades`
#

CREATE TABLE `prefix_webquest_grades` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `webquestid` int(10) unsigned NOT NULL default '0', 
  `sid` int(10) unsigned NOT NULL default '0',
  `taskno` int(10) unsigned NOT NULL default '0',
  `feedback` text,
  `grade` tinyint(3) NOT NULL default '0',
  PRIMARY KEY  (`id`),
  KEY `sid` (`sid`),
  KEY `webquestid` (`webquestid`)
) COMMENT='Info about individual grades given to each task';
# --------------------------------------------------------

#
# Table structure for table `prefix_webquest_resources`
#

CREATE TABLE `prefix_webquest_resources` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `webquestid` int(10) unsigned NOT NULL default '0',
  `name` varchar(255) NOT NULL default '',
  `description` text,
  `path` varchar(255) NOT NULL default '',
  `resno` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`id`),
  KEY `webquestid` (`webquestid`)
) COMMENT='Info about each resource';
#------------------------------------------------------------

#
# Table structure for table `prefix_webquest_teams`
#

CREATE TABLE `prefix_webquest_teams` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `webquestid` int(10) unsigned NOT NULL default '0',
  `name` varchar(255) NOT NULL default '',
  `description` text,
  PRIMARY KEY  (`id`),
  KEY `webquestid` (`webquestid`)
) COMMENT='Info about each team';
#---------------------------------------------------------------

#
# Table structure for table `prefix_webquest_team_members`
#

CREATE TABLE `prefix_webquest_team_members` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `teamid` int(10) unsigned NOT NULL default '0',
  `webquestid` int(10) unsigned NOT NULL default '0',
  `userid` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`id`),
  KEY `teamid` (`teamid`),
  INDEX `webquestid` (`webquestid`),
  INDEX `userid` (`userid`)
) COMMENT='Info about member of a team';
#--------------------------------------------------------------
