# This file contains a complete database schema for all the 
# tables used by WebQuest module, under PostgreSQL

#
# Table structure for table webquest
#
BEGIN;
CREATE TABLE prefix_webquest (
  id SERIAL PRIMARY KEY,
  course INT8 NOT NULL default '0',
  name varchar(255) NOT NULL default '',
  description text,
  process text,
  conclussion text,
  taskdescription text,
  nattachments INT NOT NULL DEFAULT '0',
  gradingstrategy INT2  NOT NULL default '1',
  maxbytes INT8  NOT NULL default '100000',
  submissionstart INT8  NOT NULL default '0',
  submissionend INT8  NOT NULL default '0',
  grade INT8 NOT NULL default '0',
  teamsmode INT NOT NULL DEFAULT '0',
  timemodified INT8  NOT NULL default '0',
  ntasks INT NOT NULL default '1',
  usepassword INT NOT NULL DEFAULT '0',
  password VARCHAR(32) NOT NULL DEFAULT ''
);

CREATE INDEX prefix_webquest_course_idx ON prefix_webquest (course);

# --------------------------------------------------------

#
# Table structure for table webquest_submissions
#


CREATE TABLE prefix_webquest_submissions (
  id SERIAL PRIMARY KEY,
  webquestid INT8  NOT NULL default '0',
  title varchar(100) NOT NULL default '',
  description text,
  userid INT8  NOT NULL default '0',
  timecreated INT8  NOT NULL default '0',
  mailed INT2  NOT NULL default '0',
  timegraded INT8  NOT NULL default '0',
  grade float NOT NULL default '0',
  gradecomment text
);

CREATE INDEX prefix_webquest_submissions_webquestid_idx ON prefix_webquest_submissions (webquestid);

#------------------------------------------------------------

#
# Table structure for table webquest_tasks
#

CREATE TABLE prefix_webquest_tasks (
  id SERIAL PRIMARY KEY,
  webquestid INT8  NOT NULL default '0',
  taskno INT  NOT NULL default '0',
  description text,
  scale INT  NOT NULL default '0',
  maxscore INT  NOT NULL default '1',
  weight INT4 NOT NULL default '1',
  stddev FLOAT NOT NULL default '0',
  totalassessments INT8 NOT NULL DEFAULT '0'
);

CREATE INDEX prefix_webquest_tasks_webquestid_idx ON prefix_webquest_tasks (webquestid);

# --------------------------------------------------------

#
# Table structure for table webquest_rubrics
#

CREATE TABLE prefix_webquest_rubrics (
  id SERIAL PRIMARY KEY,
  webquestid int8 NOT NULL default '0',
  description text,
  taskno int8  NOT NULL default '0',
  rubricno int4  NOT NULL default '0'
);

CREATE INDEX prefix_webquest_rubrics_webquestid_idx ON prefix_webquest_rubrics (webquestid);

# --------------------------------------------------------

#
# Table structure for table webquest_grades
#

CREATE TABLE prefix_webquest_grades (
  id SERIAL PRIMARY KEY,
  webquestid int8 NOT NULL default '0', 
  sid int8 NOT NULL default '0',
  taskno INT8  NOT NULL default '0',
  feedback text,
  grade INT NOT NULL default '0'
);

CREATE INDEX prefix_webquest_grades_webquestid_idx ON prefix_webquest_grades (webquestid);
CREATE INDEX prefix_webquest_grades_sid_idx ON prefix_webquest_grades (sid);

# --------------------------------------------------------

#
# Table structure for table prefix_webquest_resources
#

CREATE TABLE prefix_webquest_resources (
  id SERIAL PRIMARY KEY,
  webquestid INT8  NOT NULL default '0',
  name varchar(255) NOT NULL default '',
  description text,
  path varchar(255) NOT NULL default '',
  resno INT8  NOT NULL default '0'
);

CREATE INDEX prefix_webquest_resources_webquestid_idx ON prefix_webquest_resources (webquestid);

#------------------------------------------------------------

#
# Table structure for table prefix_webquest_teams
#

CREATE TABLE prefix_webquest_teams (
  id SERIAL PRIMARY KEY,
  webquestid INT8  NOT NULL default '0',
  name varchar(255) NOT NULL default '',
  description text
);

CREATE INDEX prefix_webquest_teams_webquestid_idx ON prefix_webquest_teams (webquestid);

#---------------------------------------------------------------

#
# Table structure for table prefix_webquest_team_members
#

CREATE TABLE prefix_webquest_team_members (
  id SERIAL PRIMARY KEY,
  teamid INT8  NOT NULL default '0',
  webquestid INT8  NOT NULL default '0',
  userid INT8  NOT NULL default '0'
);

CREATE INDEX prefix_webquest_team_members_teamid_idx ON prefix_webquest_team_members (teamid);
CREATE INDEX prefix_webquest_team_members_webquestid_idx ON prefix_webquest_team_members (webquestid);
CREATE INDEX prefix_webquest_team_members_userid_idx ON prefix_webquest_team_members (userid);

#--------------------------------------------------------------
